==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/TypescriptConfig.java <==
package io.github.cdklabs.projen.javascript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.890Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.TypescriptConfig")
public class TypescriptConfig extends software.amazon.jsii.JsiiObject {

    protected TypescriptConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TypescriptConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TypescriptConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.NodeProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.TypescriptConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addExclude(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addExclude", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addInclude(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addInclude", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions getCompilerOptions() {
        return software.amazon.jsii.Kernel.get(this, "compilerOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getExclude() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getInclude() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.TypescriptConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.TypescriptConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.javascript.NodeProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.javascript.NodeProject project;
        private final io.github.cdklabs.projen.javascript.TypescriptConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.javascript.NodeProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.javascript.TypescriptConfigOptions.Builder();
        }

        /**
         * (experimental) Compiler options to use.
         * <p>
         * @return {@code this}
         * @param compilerOptions Compiler options to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder compilerOptions(final io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions) {
            this.options.compilerOptions(compilerOptions);
            return this;
        }

        /**
         * (experimental) Filters results from the "include" option.
         * <p>
         * Default: - node_modules is excluded by default
         * <p>
         * @return {@code this}
         * @param exclude Filters results from the "include" option. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(final java.util.List<java.lang.String> exclude) {
            this.options.exclude(exclude);
            return this;
        }

        /**
         * Default: "tsconfig.json"
         * <p>
         * @return {@code this}
         * @param fileName This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(final java.lang.String fileName) {
            this.options.fileName(fileName);
            return this;
        }

        /**
         * (experimental) Specifies a list of glob patterns that match TypeScript files to be included in compilation.
         * <p>
         * Default: - all .ts files recursively
         * <p>
         * @return {@code this}
         * @param include Specifies a list of glob patterns that match TypeScript files to be included in compilation. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(final java.util.List<java.lang.String> include) {
            this.options.include(include);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.javascript.TypescriptConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.TypescriptConfig build() {
            return new io.github.cdklabs.projen.javascript.TypescriptConfig(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/TypescriptConfig.java <==
package io.github.cdklabs.projen.javascript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.548Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.TypescriptConfig")
public class TypescriptConfig extends io.github.cdklabs.projen.Component {

    protected TypescriptConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TypescriptConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TypescriptConfig(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.TypescriptConfigOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addExclude(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addExclude", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Extend from base <code>TypescriptConfig</code> instance.
     * <p>
     * @param value Base <code>TypescriptConfig</code> instance. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addExtends(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.TypescriptConfig value) {
        software.amazon.jsii.Kernel.call(this, "addExtends", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param pattern This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addInclude(final @org.jetbrains.annotations.NotNull java.lang.String pattern) {
        software.amazon.jsii.Kernel.call(this, "addInclude", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(pattern, "pattern is required") });
    }

    /**
     * (experimental) Called before synthesis.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void preSynthesize() {
        software.amazon.jsii.Kernel.call(this, "preSynthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) Resolve valid TypeScript extends paths relative to this config.
     * <p>
     * @param configPath Path to resolve against. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String resolveExtendsPath(final @org.jetbrains.annotations.NotNull java.lang.String configPath) {
        return software.amazon.jsii.Kernel.call(this, "resolveExtendsPath", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(configPath, "configPath is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions getCompilerOptions() {
        return software.amazon.jsii.Kernel.get(this, "compilerOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getExclude() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) Array of base <code>tsconfig.json</code> paths. Any absolute paths are resolved relative to this instance, while any relative paths are used as is.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getExtendsValue() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "extends", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.JsonFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.JsonFile.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getInclude() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.javascript.TypescriptConfig}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.javascript.TypescriptConfig> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.javascript.TypescriptConfigOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.javascript.TypescriptConfigOptions.Builder();
        }

        /**
         * (experimental) Compiler options to use.
         * <p>
         * @return {@code this}
         * @param compilerOptions Compiler options to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder compilerOptions(final io.github.cdklabs.projen.javascript.TypeScriptCompilerOptions compilerOptions) {
            this.options.compilerOptions(compilerOptions);
            return this;
        }

        /**
         * (experimental) Filters results from the "include" option.
         * <p>
         * Default: - node_modules is excluded by default
         * <p>
         * @return {@code this}
         * @param exclude Filters results from the "include" option. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder exclude(final java.util.List<java.lang.String> exclude) {
            this.options.exclude(exclude);
            return this;
        }

        /**
         * (experimental) Base <code>tsconfig.json</code> configuration(s) to inherit from.
         * <p>
         * @return {@code this}
         * @param extendsValue Base <code>tsconfig.json</code> configuration(s) to inherit from. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder extendsValue(final io.github.cdklabs.projen.javascript.TypescriptConfigExtends extendsValue) {
            this.options.extendsValue(extendsValue);
            return this;
        }

        /**
         * Default: "tsconfig.json"
         * <p>
         * @return {@code this}
         * @param fileName This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fileName(final java.lang.String fileName) {
            this.options.fileName(fileName);
            return this;
        }

        /**
         * (experimental) Specifies a list of glob patterns that match TypeScript files to be included in compilation.
         * <p>
         * Default: - all .ts files recursively
         * <p>
         * @return {@code this}
         * @param include Specifies a list of glob patterns that match TypeScript files to be included in compilation. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder include(final java.util.List<java.lang.String> include) {
            this.options.include(include);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.javascript.TypescriptConfig}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.javascript.TypescriptConfig build() {
            return new io.github.cdklabs.projen.javascript.TypescriptConfig(
                this.project,
                this.options.build()
            );
        }
    }
}
